History
========

0.3.3 (2012-07-31)
~~~~~~~~~~~~~~~~~~~
* Fix `issue #6 <https://github.com/ikeikeikeike/django-spine/issues/6>`_

0.3.2 (2012-07-17)
~~~~~~~~~~~~~~~~~~~
* Fix setup module

  - `issue #3 <https://github.com/ikeikeikeike/django-spine/issues/3>`_
  - `issue #5 <https://github.com/ikeikeikeike/django-spine/issues/5>`_

0.0.2 (2012-06-17)
~~~~~~~~~~~~~~~~~~~
* Added the django-pipeline and eco package to requirements.txt
* modify examples
* modify README.rst

0.0.1 (2012-06-16)
~~~~~~~~~~~~~~~~~~~
* Alpha


